package com.jtyjy.pdf2pptx.converter;

import com.jtyjy.pdf2pptx.support.Constant;
import com.jtyjy.pdf2pptx.support.FileUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
/**
 * pdf转pptx
 * 常量Constant.SOURCE_PATH为待转换文件根目录
 *
 * @author guan
 */
@Component
public class Pdf2Pptx {

    private static final Logger logger = LoggerFactory.getLogger(Pdf2Pptx.class);

    public static void main(String[] args) {
        //读取指定文件夹下所有文件并转换为图片
//        conver(Constant.SOURCE_PATH);
        //删除所有生成的图片文件
        List<String> allDirPathName = new ArrayList<>();
        FileUtil.getAllDirPathNameRe(Constant.SOURCE_PATH, allDirPathName);
        for (String delFolder : allDirPathName) {
            if (delFolder(delFolder)) {
                logger.info("删除文件夹：{}及其文件成功", delFolder);
            }
        }
    }

    public void converte(String path) {
        conver(path);
    }

    private static void conver(String path) {
        //读取指定文件夹下所有文件并转换为图片
        List<String> allFilePathName = new ArrayList<>();

        FileUtil.getAllFilePathNameRe(path, allFilePathName);
        for (String filePathName : allFilePathName) {
            File file = new File(filePathName);
            if (file.getName().endsWith(".pdf")) {
                //判断图片是否存在
                List<String> allDirPathName = new ArrayList<>();
                FileUtil.getAllDirPathNameRe(path, allDirPathName);
                if (!allDirPathName.contains(file.getAbsolutePath().replace(".pdf", "_图片"))) {
                    logger.info("转换pdf：{} 为图片开始", file.getAbsolutePath());
                    long begin = System.currentTimeMillis();
                    Pdf2Png.pdf2Image(file.getAbsolutePath(), file.getParent(), 350);
                    long end = System.currentTimeMillis();
                    logger.info("转换pdf：{} 为图片完成，耗时{}ms", file.getAbsolutePath(), end - begin);
                } else {
                    logger.info("文件：{} 已经转换", file.getName());
                }
            }
        }
        logger.info("======== pdf转图片已完成，准备生成pptx ========");
        try {
            Thread.sleep(5000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        //将图片插入PPT
        List<String> allDirPathName = new ArrayList<>();
        FileUtil.getAllDirPathNameRe(path, allDirPathName);
        for (String dirPathName : allDirPathName) {
            File dir = new File(dirPathName);
            //判断ppt是否存在
            if (dir.getName().endsWith("_图片")) {
                List<String> allPptPathFileName = new ArrayList<>();
                FileUtil.getAllFilePathNameRe(path, allPptPathFileName);
                if (!allPptPathFileName.contains(dir.getAbsolutePath().replace("_图片", ".pptx"))) {
                    List<String> filePathNames = FileUtil.getAllFilePathName(dir.getAbsolutePath());
                    //转换
                    logger.info("开始转换图片：{} 为pptx", dir.getName());
                    long begin = System.currentTimeMillis();
                    Png2Pptx.createPicturePptx(filePathNames, dir);
                    long end = System.currentTimeMillis();
                    logger.info("转换图片：{} 为pptx完成,耗时：{}ms", dir.getName(), end - begin);
                } else {
                    logger.info("文件：{} 已经存在", dir.getName() + ".pptx");
                }
            }

        }
        //删除所有生成的图片文件
        for (String dirPathName : allDirPathName) {
            if (delFolder(dirPathName)) {
                logger.info("删除文件夹：{}及其文件成功", dirPathName);
            }
        }
    }

    //删除指定文件夹下所有文件
    public static boolean delAllFile(String path) {
        boolean flag = false;
        File file = new File(path);
        if (!file.exists()) {
            return flag;
        }
        if (!file.isDirectory()) {
            return flag;
        }
        String[] tempList = file.list();
        File temp = null;
        for (int i = 0; i < tempList.length; i++) {
            if (path.endsWith(File.separator)) {
                temp = new File(path + tempList[i]);
            } else {
                temp = new File(path + File.separator + tempList[i]);
            }
            if (temp.isFile()) {
                temp.delete();
            }
            if (temp.isDirectory()) {
                delAllFile(path + "/" + tempList[i]);//先删除文件夹里面的文件
                delFolder(path + "/" + tempList[i]);//再删除空文件夹
                flag = true;
            }
        }
        return flag;
    }

    //删除文件夹
    //param folderPath 文件夹完整绝对路径

    public static boolean delFolder(String folderPath) {
        try {
            delAllFile(folderPath); //删除完里面所有内容
            String filePath = folderPath;
            filePath = filePath.toString();
            java.io.File myFilePath = new java.io.File(filePath);
            return myFilePath.delete(); //删除空文件夹
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }


}
